@@ -13,7 +13,7 @@ class AppEnvironmentClusterEnvChoices(ChoiceSet):
         (CHOICE_PRD, 'PRD', 'red'),
         (CHOICE_INT, 'INT', 'yellow'),
         (CHOICE_TST, 'TST', 'cyan'),
-        (CHOICE_DEV, 'DEV', 'green'),
+        (CHOICE_DEV, 'DEV', 'light green'),
     ]
 
 
