@@ -1,10 +1,9 @@
-from django.core.validators import RegexValidator
 from django.forms import (
     CharField,
     BooleanField, PasswordInput, ModelChoiceField,
 )
 
-from ipam.models import IPAddress, Prefix
+from ipam.models import Prefix, IPAddress
 from netbox.forms import (
     NetBoxModelBulkEditForm,
     NetBoxModelFilterSetForm,
@@ -12,31 +11,65 @@ from netbox.forms import (
     NetBoxModelForm,
 )
 from ocp_project_plugin.models import AppEnvironment, OCPProject
-from utilities.forms import DynamicModelChoiceField
+from utilities.forms import DynamicModelChoiceField, APISelectMultiple, CSVModelChoiceField
 
 
-memory_validator = RegexValidator(r"[1-9][0-9]*(Mi|Gi)$", "The input should contain only positive Number, which ends "
-                                                          "with Mi (Megabyte) or Gi (Gigabyte)")
-
-
-class AppEnvironmentForm(NetBoxModelForm):
+class AppEnvironmentAddForm(NetBoxModelForm):
     """Form for creating a new App Environment object."""
-    #requests_memory = CharField(
-    #    max_length=5,
-    #    label="Memory request",
-    #    help_text="The memory value e.g. 200Mi or 1Gi",
-    #    validators=[memory_validator],
-    #)
     ocp_project = DynamicModelChoiceField(
         queryset=OCPProject.objects.all(),
         label="OCP Project",
         help_text="Choose the ocp project e.g. web shop",
     )
-    egress_ip = ModelChoiceField(
-        queryset=Prefix.get_child_ips(Prefix.objects.get(prefix='10.190.1.64/26')),
-        #queryset=IPAddress.objects.filter(address__net_host_contained='10.190.1.64/26'),
+    egress_ip = DynamicModelChoiceField(
+        queryset=IPAddress.objects.all(),
+        #queryset=Prefix.get_child_ips(Prefix.objects.get(prefix='10.190.1.64/26')),
+        #queryset=IPAddress.objects.all(),
         label="Egress IP",
         help_text="Select your egress ip",
+        widget=APISelectMultiple(
+            api_url='/api/ipam/ip-addresses/?q=&parent=10.190.1.64/26',
+        ),
+        required=False
+    )
+
+    fieldsets = (
+        ('OCP Project', ['ocp_project']),
+        ('Environment', ('cluster_env', 'app_env')),
+        ('Deployment', ('repo', 'branch', 'access_token', 'path', 'deployment_kind')),
+        ('Monitoring', ('monitoring', 'postgres_monitoring')),
+        ('Resources', ('limits_cpu', 'limits_memory', 'requests_cpu', 'requests_memory')),
+        ('Additional Config', ('mtls', 'egress_ip')),
+    )
+
+    class Meta:
+        model = AppEnvironment
+
+        fields = ["access_token", "cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind", "monitoring",
+                  "postgres_monitoring", "ocp_project", "requests_cpu", "requests_memory", "limits_cpu",
+                  "limits_memory"]
+
+        widgets = {
+            'access_token': PasswordInput(),
+        }
+
+
+class AppEnvironmentEditForm(NetBoxModelForm):
+    """Form for creating a new App Environment object."""
+    ocp_project = DynamicModelChoiceField(
+        queryset=OCPProject.objects.all(),
+        label="OCP Project",
+        help_text="Choose the ocp project e.g. web shop",
+        disabled=True
+    )
+    egress_ip = DynamicModelChoiceField(
+        queryset=IPAddress.objects.all(),
+        label="Egress IP",
+        help_text="Select your egress ip",
+        widget=APISelectMultiple(
+            api_url='/api/ipam/ip-addresses/?q=&parent=10.190.1.64/26',
+        ),
+        required = False
     )
 
     fieldsets = (
@@ -109,6 +142,10 @@ class AppEnvironmentFilterForm(NetBoxModelFilterSetForm):
 
 
 class AppEnvironmentImportForm(NetBoxModelImportForm):
+    cluster_env = CharField(
+        label="App Env",
+        help_text="The app Env String used for creating the namespace e.g. tst",
+    )
     app_env = CharField(
         label="App Env",
         help_text="The app Env String used for creating the namespace e.g. tst",
@@ -132,6 +169,7 @@ class AppEnvironmentImportForm(NetBoxModelImportForm):
         help_text="Path of the deployment files e.g. overlays/tst"
     )
     egress_ip = CharField(
+        required=False,
         label="Egress IP",
         help_text="The egress IP e.g. 10.10.10.10"
     )
@@ -145,11 +183,16 @@ class AppEnvironmentImportForm(NetBoxModelImportForm):
         label="Postgres Monitoring",
         help_text="Enable if postgres monitoring should be used",
     )
+    ocp_project = CSVModelChoiceField(
+        queryset=OCPProject.objects.all(),
+        to_field_name='name',
+        help_text='Choose the ocpproject'
+    )
 
     class Meta:
         model = AppEnvironment
 
-        fields = ["app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind", "monitoring", "postgres_monitoring",
+        fields = ["cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind", "monitoring", "postgres_monitoring",
                   "ocp_project"]
 
 
